@@ -37,7 +37,9 @@ from python_kemptech_api.objects import (
     Range,
     CustomLocation,
     Interface,
-    IntermediateCertificate)
+    IntermediateCertificate,
+    License,
+    Subscription)
 from python_kemptech_api.utils import (
     send_response,
     validate_port,
@@ -150,12 +152,7 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
         curl.append(command)
         return curl
 
-    @property
-    def license(self):
-        """Current license on the LoadMaster
-
-        :return: License information
-        """
+    def _get_license(self, as_object=False):
         response = self._get("/licenseinfo")
 
         if is_successful(response):
@@ -186,7 +183,33 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
         else:
             raise KempTechApiException(get_error_msg(response))
 
-        return license_info
+        if as_object is True:
+            subscriptions = [
+                build_object(Subscription, self.access_info, item[1])
+                for item in license_info.items()
+                if item[0].startswith('subscriptionentry')
+            ]
+            lic_obj = build_object(License, self.access_info, license_info)
+            lic_obj.subscriptions = subscriptions
+            return lic_obj
+        else:
+            return license_info
+
+    @property
+    def license(self):
+        """Current license on the LoadMaster
+
+        :return: License information
+        """
+        return self._get_license()
+
+    @property
+    def license_as_object(self):
+        """Current license on the LoadMaster as an object
+
+        :return: License information
+        """
+        return self._get_license(as_object=True)
 
     @property
     def interfaces(self):
